@@ -190,59 +190,6 @@ class Device(Events):
     def serial_number(self):
         return self.__serialNumber
 
-    def upload_file(self, file_path, remote_path):
-        file_name = file_path.split("/")[len(file_path.split("/")) - 1]
-        if file_name == "":
-            raise Exception('error: the file path format is incorrect, and the transfer folder is not supported')
-        if remote_path.split("/")[len(remote_path.split("/")) - 1] == "":
-            remote_path += file_name
-        header = {
-            "content-type": "application/json",
-            "FileName": remote_path
-        }
-        data = {'file': (file_name, open(file_path, 'rb').read())}
-        encode_data = encode_multipart_formdata(data)
-        data = encode_data[0]
-        header['Content-Type'] = encode_data[1]
-        return bool(int(str(self.con.post(path="upLoadFile", headers=header, data=data).read(), 'utf-8')))
-
-    def file_exist(self, file_path):
-        return bool(int(str(self.con.get(path="checkFileExist", args="filename=" + file_path).read(), 'utf-8')))
-
-    def file_remove(self, file_path):
-        return bool(int(str(self.con.get(path="fileRemove", args="filename=" + file_path).read(), 'utf-8')))
-
-    def file_move(self, source_path, target_path):
-        return bool(int(str(self.con.get(path="fileMove", args="source=" + source_path + "&target=" + target_path).read(), 'utf-8')))
-
-    def file_copy(self, source_path, target_path):
-        return bool(int(str(self.con.get(path="fileCopy", args="source=" + source_path + "&target=" + target_path).read(), 'utf-8')))
-
-    def dir_exist(self, dir_path):
-        return self.file_exist(dir_path)
-
-    def mkdir(self, dir_path):
-        return bool(int(str(self.con.get(path="mkdir", args="dirname=" + dir_path).read(), 'utf-8')))
-
-    def is_installed(self, sopid):
-        return bool(int(str(self.con.get(path="isAppInstalled", args="sopid=" + sopid).read(), 'utf-8')))
-
-    def is_uninstallable(self, sopid):
-        return bool(int(str(self.con.get(path="isAppUninstallable", args="sopid=" + sopid).read(), 'utf-8')))
-
-    def install(self, file_path):
-        if self.upload_file(file_path, "/tmp/"):
-            file_name = file_path.split("/")[len(file_path.split("/")) - 1]
-            self.con.get(path="install", args="filepath=/tmp/" + file_name)
-            return True
-        return False
-
-    def uninstall(self, sopid):
-        return bool(int(str(self.con.get(path="uninstall", args="sopid=" + sopid).read(), 'utf-8')))
-
-    def system_time(self):
-        return int(str(self.con.get(path="getDatetime").read(), 'utf-8'))
-
     def log(self, level, text):
         pass
         # if not self.__runner_log:
